from openfisca_core.model_api import *

from openfisca_senegal.entities import *


class impots_indirects(Variable):
    value_type = float
    entity = Household
    definition_period = YEAR

    def formula(menage, period):
        return menage("tva", period)



from openfisca_senegal import CountryTaxBenefitSystem as SenegalTBS
from openfisca_senegal.scenarios import init_single_entity

tax_benefit_system = SenegalTBS()

scenario = tax_benefit_system.new_scenario()

init_single_entity(
    scenario,
    parent1={
        "salaire": 1800000,
        "est_marie": True,
        "conjoint_a_des_revenus": False,
        "nombre_enfants": 2,
    },
    period="2015",
)

simulation = scenario.new_simulation()

# print('Salaire retenu :')
# print(simulation.individu('salaire', period='2015'))
# print('Impot avant réduction famille :')
# print(simulation.individu('impot_avant_reduction_famille', period='2015'))
# print('Réduction pour charge famille :')
# print(simulation.individu('reduction_impots_pour_charge_famille', period='2015'))
# print('Impot pour la famille :')
# print(simulation.individu('impot_revenus', period='2015'))



import configparser
import logging
import os

from openfisca_core.taxbenefitsystems import TaxBenefitSystem

__version__ = "0.11.2"
from openfisca_senegal import entities

log = logging.getLogger(__name__)


COUNTRY_DIR = os.path.dirname(os.path.abspath(__file__))


# Our country tax and benefit class inherits from the general TaxBenefitSystem class.
# The name CountryTaxBenefitSystem must not be changed, as all tools of the OpenFisca ecosystem expect a
# CountryTaxBenefitSystem class to be exposed in the __init__ module of a country package.
class CountryTaxBenefitSystem(TaxBenefitSystem):
    CURRENCY = "FCFA"

    def __init__(self):
        # We initialize our tax and benefit system with the general constructor
        super(CountryTaxBenefitSystem, self).__init__(entities.entities)

        # We add to our tax and benefit system all the variables
        self.add_variables_from_directory(os.path.join(COUNTRY_DIR, "variables"))

        # We add to our tax and benefit system all the legislation parameters defined in the  parameters files
        param_path = os.path.join(COUNTRY_DIR, "parameters")
        self.load_parameters(param_path)
        try:
            from openfisca_ceq.tests.test_indirect_tax_variables_generator import add_coicop_item_to_tax_benefit_system

            add_coicop_item_to_tax_benefit_system(self, country="senegal")
        except (configparser.NoSectionError, ModuleNotFoundError) as e:
            log.info("No ceq baecause:")
            log.info(e)
            log.info("Passing")



from openfisca_core.model_api import *

from openfisca_senegal.entities import *


class household_weight(Variable):
    default_value = 1.0
    is_period_size_independent = True
    value_type = float
    entity = Household
    label = "Poids du ménage"
    definition_period = YEAR


class person_weight(Variable):
    default_value = 1.0
    is_period_size_independent = True
    value_type = float
    entity = Person
    label = "Poids de l'individ"
    definition_period = YEAR



import configparser
import logging
import os

import pandas as pd
from openfisca_core import periods
from openfisca_survey_manager.paths import default_config_files_directory as config_files_directory

log = logging.getLogger(__file__)


config_parser = configparser.ConfigParser()
config_parser.read(os.path.join(config_files_directory, "raw_data.ini"))
data_is_available = config_parser.has_section("senegal")
if not data_is_available:
    log.info("No data available for Sénégal")


def get_data_file_path():
    file_path_by_year = dict(config_parser.items("senegal"))
    return file_path_by_year["2011"]


def create_dataframes_from_stata_data():
    data_file_path = get_data_file_path()
    # dico_labels = pd.read_stata(data_file_path, iterator=True)
    # import pprint
    # pprint.pprint(dico_labels.variable_labels())
    dataframe = pd.read_stata(data_file_path)
    person_variables = [
        "age",
        "hhid",
        "link_to_head",
        "mstatus_ind",
        "inc_pension_ind",
        "weight_pc",
        "sex",
        "wage_formal_ind",
    ]

    person_dataframe = dataframe[person_variables].copy()
    person_dataframe["age"] = (
        person_dataframe["age"]
        .replace(
            {
                "98 ans et plus": "98.0",
                "NSP": "50.0",
            }
        )
        .fillna("50")
        .astype(float)
        .astype(int)
    )

    person_dataframe["salaire"] = person_dataframe.wage_formal_ind
    assert (
        person_dataframe.mstatus_ind.isin(
            [
                "Celibataire",
                "Marie",
                "Non concerne",
                "Veuf, Divorce",
            ]
        )
    ).all()
    person_dataframe["statut_marital"] = person_dataframe.mstatus_ind.map(
        {
            "Marie": 0,
            "Celibataire": 1,
            "Veuf, Divorce": 2,
            "Non concerne": 3,
        }
    )
    assert (person_dataframe.statut_marital.isin([0, 1, 2, 3])).all()
    # print(person_dataframe.link_to_head.value_counts())
    person_dataframe["household_role_index"] = (
        0 * (person_dataframe.link_to_head == 1)
        + 1 * (person_dataframe.link_to_head == 2)
        + 2 * (person_dataframe.link_to_head > 2)
    )

    household_id_by_hhid = (
        person_dataframe.hhid.drop_duplicates()
        .sort_values()
        .reset_index(drop=True)
        .reset_index()
        .rename(columns={"index": "household_id"})
        .set_index("hhid")
        .squeeze()
    )
    person_dataframe["household_id"] = person_dataframe["hhid"].map(household_id_by_hhid)
    person_dataframe["person_id"] = range(len(person_dataframe))
    person_dataframe = person_dataframe.rename(
        columns={
            "inc_pension_ind": "pension",
            "sex": "sexe",
            "weight_pc": "person_weight",
        }
    )

    assert (dataframe.groupby("hhid")["weight_pc"].nunique() == 1).all()

    household_weight = dataframe.groupby("hhid")["weight_pc"].mean()
    household_dataframe = pd.DataFrame(
        dict(
            household_id=range(person_dataframe.household_id.max() + 1),
            household_weight=household_weight.values,
        )
    )
    return person_dataframe, household_dataframe


def create_data_from_stata(create_dataframes=True):
    year = 2017
    data = dict()

    if create_dataframes:
        person_dataframe, household_dataframe = create_dataframes_from_stata_data()
        input_data_frame_by_entity = {
            "person": person_dataframe,
            "household": household_dataframe,
        }
        input_data_frame_by_entity_by_period = {periods.period(year): input_data_frame_by_entity}
        data["input_data_frame_by_entity_by_period"] = input_data_frame_by_entity_by_period

    else:
        data_file_path = get_data_file_path()
        data["stata_file_by_entity"] = dict(
            # household = os.path.join(data_directory, 'household.dta'),
            person=data_file_path,
        )
    return data


if __name__ == "__main__":
    import sys

    logging.basicConfig(level=logging.DEBUG, stream=sys.stdout)
    person_dataframe, household_dataframe = create_dataframes_from_stata_data()
    data = create_data_from_stata()



import os

from openfisca_core.taxbenefitsystems import TaxBenefitSystem

from openfisca_senegal import entities

COUNTRY_DIR = os.path.dirname(os.path.abspath(__file__))


class SenegalTaxBenefitSystem(TaxBenefitSystem):
    """Senegalese tax and benefit system"""

    CURRENCY = "FCFA"

    def __init__(self):
        super(SenegalTaxBenefitSystem, self).__init__(entities.entities)
        self.add_variables_from_directory(os.path.join(COUNTRY_DIR, "variables"))
        self.load_parameters(os.path.join(COUNTRY_DIR, "parameters"))



import logging
import os
import sys

import pytest

from openfisca_senegal import CountryTaxBenefitSystem as SenegalTaxBenefitSystem
from openfisca_senegal.input_data_builder import data_is_available
from openfisca_senegal.survey_scenarios import SenegalSurveyScenario
from openfisca_senegal.tests.test_survey_scenario_from_stata_data import (
    create_data_from_stata,
)

log = logging.getLogger(__name__)


@pytest.mark.skip(
    reason="FileNotFoundError: [Errno 2] No such file or directory: '/home/benjello/Dropbox/Projet_Micro_Sim/B_all_final_dta/TaxeIneq_prep_inc_SEN.dta'"
)
def test_add_ceq_framework_to_senegal():
    circleci = "CIRCLECI" in os.environ
    if circleci:
        return

    from openfisca_ceq.tools.tax_benefit_system_ceq_completion import ceq

    tax_benefit_system = SenegalTaxBenefitSystem()
    tax_benefit_system.legislation_country = "senegal"
    ceq_enhanced_tax_benefit_system = ceq(tax_benefit_system)
    if not data_is_available:
        return
    data = create_data_from_stata()
    survey_scenario = SenegalSurveyScenario(
        tax_benefit_system=ceq_enhanced_tax_benefit_system,
        data=data,
        year=2017,
    )
    log.info(survey_scenario.calculate_variable("impot_revenus", period=2017)[0:10])
    log.info(survey_scenario.calculate_variable("personal_income_tax", period=2017).sum())
    log.info(survey_scenario.compute_aggregate("personal_income_tax", period=2017))
    return survey_scenario


if __name__ == "__main__":
    logging.basicConfig(level=logging.INFO, stream=sys.stdout)
    test_add_ceq_framework_to_senegal()



from openfisca_core.model_api import *

from openfisca_senegal.entities import *


class benefices_non_salarie(Variable):
    value_type = float
    entity = Person
    label = "Bénéfices non salarié"
    definition_period = YEAR


class conjoint_a_des_revenus(Variable):
    value_type = bool
    entity = Person
    definition_period = YEAR


class pension_retraite(Variable):
    value_type = float
    entity = Person
    label = "Pension Retraite"
    definition_period = YEAR


class salaire(Variable):
    value_type = float
    entity = Person
    label = "Salaire"
    definition_period = YEAR



import logging

import pytest

from openfisca_senegal.input_data_builder import (
    create_data_from_stata,
)
from openfisca_senegal.survey_scenarios import SenegalSurveyScenario

log = logging.getLogger(__file__)


@pytest.mark.skip(
    reason="FileNotFoundError: [Errno 2] No such file or directory: '/home/benjello/Dropbox/Projet_Micro_Sim/B_all_final_dta/TaxeIneq_prep_inc_SEN.dta'"
)
def test_survey_scenario(create_dataframes=True):
    year = 2017
    data = create_data_from_stata(create_dataframes=create_dataframes)
    survey_scenario = SenegalSurveyScenario(
        data=data,
        year=year,
    )
    df_by_entity = survey_scenario.create_data_frame_by_entity(
        variables=["age", "salaire", "impot_avant_reduction_famille", "impot_revenus", "household_weight"]
    )

    for entity, df in df_by_entity.items():
        assert not df.empty, "{} dataframe is empty".format(entity)
        log.debug(df)


if __name__ == "__main__":
    import sys

    logging.basicConfig(level=logging.DEBUG, stream=sys.stdout)
    test_survey_scenario()



import logging

log = logging.getLogger(__name__)


# def init_single_entity(scenario, axes = None, enfants = None, household = None, parent1 = None, parent2 = None,
#         period = None):
#     if enfants is None:
#         enfants = []
#     assert parent1 is not None
#     household = household.copy() if household is not None else {}
#     persons = []
#     for index, person in enumerate([parent1, parent2] + (enfants or [])):
#         if person is None:
#             continue
#         id = person.get('id')
#         if id is None:
#             person = person.copy()
#             person['id'] = id = 'ind{}'.format(index)
#         persons.append(person)
#         if index <= 1:
#             household.setdefault('parents', []).append(id)
#         else:
#             household.setdefault('enfants', []).append(id)
#     household.setdefault('enfants', [])
#     conv.check(self.make_json_or_python_to_attributes())(dict(
#         axes = axes,
#         period = period,
#         test_case = dict(
#             households = [household],
#             persons = persons,
#             ),
#         ))
#     return self


def init_single_entity(scenario, axes=None, enfants=None, household=None, parent1=None, parent2=None, period=None):
    if enfants is None:
        enfants = []
    assert parent1 is not None

    households = {}
    persons = {}

    count_so_far = 0
    for nth in range(0, 1):
        household_nth = household.copy() if household is not None else {}
        group = [parent1, parent2] + (enfants or [])
        for index, person in enumerate(group):
            if person is None:
                continue
            id = person.get("id")
            if id is None:
                person = person.copy()
                id = "ind{}".format(index + count_so_far)
            persons[id] = person
            if index <= 1:
                if index == 0:
                    household_nth["personne_de_reference"] = id
                else:
                    household_nth["conjoint"] = id
            else:
                household_nth.setdefault("enfants", []).append(id)

        count_so_far += len(group)
        households["m{}".format(nth)] = household_nth

    test_data = {"period": period, "households": households, "persons": persons}
    if axes:
        test_data["axes"] = axes
    scenario.init_from_dict(test_data)
    return scenario



from numpy import (
    clip,
    floor_divide,
)
from openfisca_core.model_api import *

from openfisca_senegal.entities import *


class nombre_de_parts(Variable):
    value_type = float
    entity = Person
    label = "Nombre de parts"
    definition_period = YEAR

    def formula(individu, period, parameters):
        nombre_de_parts_par_enfant = parameters(period).nombre_de_parts.par_enfant
        limite_nombre_de_parts = parameters(period).nombre_de_parts.limite_max
        repartition_marie_conjoint = parameters(period).nombre_de_parts.repartition_marie_conjoint
        veuf_avec_enfant = parameters(period).nombre_de_parts.veuf_avec_enfant

        est_marie = individu("est_marie", period)
        est_veuf = individu("est_veuf", period)
        nombre_enfants = individu("nombre_enfants", period)
        parts_enfant_veuf = est_veuf * veuf_avec_enfant * min_(1, nombre_enfants)

        nombre_de_parts_enfants = nombre_enfants * nombre_de_parts_par_enfant + parts_enfant_veuf
        conjoint_a_des_revenus = individu("conjoint_a_des_revenus", period)
        nombre_de_parts_conjoint = est_marie * repartition_marie_conjoint * (1 + not_(conjoint_a_des_revenus))

        nombre_de_parts = 1 + nombre_de_parts_conjoint + nombre_de_parts_enfants

        return min_(limite_nombre_de_parts, nombre_de_parts)


class impot_avant_reduction_famille(Variable):
    value_type = float
    entity = Person
    definition_period = YEAR

    def formula(individu, period, legislation):
        salaire = individu("salaire", period, options=[ADD])
        salaire_abattement = min_(0.3 * salaire, 900000)
        salaire_imposable = salaire - salaire_abattement

        pension_retraite = individu("pension_retraite", period, options=[ADD])
        pension_abbattement = max_(pension_retraite * 0.4, 1800000) * (pension_retraite > 0)
        retraite_imposable = pension_retraite - pension_abbattement
        benefices_non_salarie = individu("benefices_non_salarie", period, options=[ADD])
        benefice_abattement = benefices_non_salarie * 0.15
        benefices_imposable = benefices_non_salarie - benefice_abattement

        revenus_arrondis = floor_divide(salaire_imposable + retraite_imposable + benefices_imposable, 1000) * 1000
        revenus_imposable = max_(0, revenus_arrondis)

        bareme_impot_progressif = legislation(period).prelevements_obligatoires.impots_directs.bareme_impot_progressif
        return bareme_impot_progressif.calc(revenus_imposable)


class reduction_impots_pour_charge_famille(Variable):
    value_type = float
    entity = Person
    definition_period = YEAR

    def formula(individu, period, legislation):
        impot_avant_reduction_famille = individu("impot_avant_reduction_famille", period)

        nombre_de_parts = individu("nombre_de_parts", period)
        reductions_pour_charge_de_famille = legislation(
            period
        ).prelevements_obligatoires.impots_directs.reductions_pour_charge_de_famille

        taux = (
            (nombre_de_parts == 1) * reductions_pour_charge_de_famille.taux_1
            + (nombre_de_parts == 1.5) * reductions_pour_charge_de_famille.taux_2
            + (nombre_de_parts == 2) * reductions_pour_charge_de_famille.taux_3
            + (nombre_de_parts == 2.5) * reductions_pour_charge_de_famille.taux_4
            + (nombre_de_parts == 3) * reductions_pour_charge_de_famille.taux_5
            + (nombre_de_parts == 3.5) * reductions_pour_charge_de_famille.taux_6
            + (nombre_de_parts == 4) * reductions_pour_charge_de_famille.taux_7
            + (nombre_de_parts == 4.5) * reductions_pour_charge_de_famille.taux_8
            + (nombre_de_parts == 5) * reductions_pour_charge_de_famille.taux_9
        )
        minimum = (
            (nombre_de_parts == 1) * reductions_pour_charge_de_famille.min_1
            + (nombre_de_parts == 1.5) * reductions_pour_charge_de_famille.min_2
            + (nombre_de_parts == 2) * reductions_pour_charge_de_famille.min_3
            + (nombre_de_parts == 2.5) * reductions_pour_charge_de_famille.min_4
            + (nombre_de_parts == 3) * reductions_pour_charge_de_famille.min_5
            + (nombre_de_parts == 3.5) * reductions_pour_charge_de_famille.min_6
            + (nombre_de_parts == 4) * reductions_pour_charge_de_famille.min_7
            + (nombre_de_parts == 4.5) * reductions_pour_charge_de_famille.min_8
            + (nombre_de_parts == 5) * reductions_pour_charge_de_famille.min_9
        )
        maximum = (
            (nombre_de_parts == 1) * reductions_pour_charge_de_famille.max_1
            + (nombre_de_parts == 1.5) * reductions_pour_charge_de_famille.max_2
            + (nombre_de_parts == 2) * reductions_pour_charge_de_famille.max_3
            + (nombre_de_parts == 2.5) * reductions_pour_charge_de_famille.max_4
            + (nombre_de_parts == 3) * reductions_pour_charge_de_famille.max_5
            + (nombre_de_parts == 3.5) * reductions_pour_charge_de_famille.max_6
            + (nombre_de_parts == 4) * reductions_pour_charge_de_famille.max_7
            + (nombre_de_parts == 4.5) * reductions_pour_charge_de_famille.max_8
            + (nombre_de_parts == 5) * reductions_pour_charge_de_famille.max_9
        )

        reduction_impot = clip(impot_avant_reduction_famille * taux, a_min=minimum, a_max=maximum)
        return reduction_impot


class impot_revenus(Variable):
    value_type = float
    entity = Person
    definition_period = YEAR

    def formula(individu, period):
        impot_avant_reduction_famille = individu("impot_avant_reduction_famille", period)
        reduction_impots_pour_charge_famille = individu("reduction_impots_pour_charge_famille", period)
        impot_apres_reduction_famille = impot_avant_reduction_famille - reduction_impots_pour_charge_famille
        return max_(0, impot_apres_reduction_famille)



import logging

import pytest

from openfisca_senegal import CountryTaxBenefitSystem as SenegalTaxBenefitSystem
from openfisca_senegal.input_data_builder import (
    create_data_from_stata,
)
from openfisca_senegal.survey_scenarios import SenegalSurveyScenario

log = logging.getLogger(__name__)


@pytest.mark.skip(
    reason="FileNotFoundError: [Errno 2] No such file or directory: '/home/benjello/Dropbox/Projet_Micro_Sim/B_all_final_dta/TaxeIneq_prep_inc_SEN.dta'"
)
def test_survey_scenario(create_dataframes=True):
    year = 2017
    data = create_data_from_stata(create_dataframes=create_dataframes)

    tax_benefit_system = SenegalTaxBenefitSystem()
    survey_scenario = SenegalSurveyScenario(
        data=data,
        year=year,
        tax_benefit_system=tax_benefit_system,
        baseline_tax_benefit_system=tax_benefit_system,
        varying_variable="salaire",
        use_marginal_tax_rate=True,
    )
    log.info(1 - survey_scenario.compute_marginal_tax_rate(target_variable="impot_revenus", period=year))
    return survey_scenario


if __name__ == "__main__":
    import sys

    logging.basicConfig(level=logging.DEBUG, stream=sys.stdout)
    survey_scenario = test_survey_scenario()



import pandas as pd
from openfisca_core import periods
from openfisca_survey_manager.scenarios.reform_scenario import ReformScenario

from openfisca_senegal import CountryTaxBenefitSystem as SenegalTaxBenefitSystem


class SenegalSurveyScenario(ReformScenario):
    weight_variable_by_entity = dict(
        household="household_weight",
        person="person_weight",
    )
    varying_variable = None

    def __init__(
        self,
        tax_benefit_system=None,
        baseline_tax_benefit_system=None,
        period=None,
        data=None,
        use_marginal_tax_rate=False,
        varying_variable=None,
        variation_factor=0.03,
    ):
        super(SenegalSurveyScenario, self).__init__()
        assert period is not None
        self.period = period

        if tax_benefit_system is None:
            tax_benefit_system = SenegalTaxBenefitSystem()
        if baseline_tax_benefit_system is not None:
            self.set_tax_benefit_systems(
                tax_benefit_systems={"reform": tax_benefit_system, "baseline": baseline_tax_benefit_system},
            )
        else:
            self.set_tax_benefit_systems(
                tax_benefit_systems={"baseline": tax_benefit_system},
            )

        if use_marginal_tax_rate:
            assert varying_variable is not None
            assert varying_variable in self.tax_benefit_system.variables
            self.variation_factor = variation_factor
            self.varying_variable = varying_variable

        if data is None:
            return

        if "input_data_frame_by_entity_by_period" in data:
            period = periods.period(period)
            dataframe_variables = set()
            for entity_dataframe in data["input_data_frame_by_entity_by_period"][period].values():
                if not isinstance(entity_dataframe, pd.DataFrame):
                    continue
                dataframe_variables = dataframe_variables.union(set(entity_dataframe.columns))
            self.used_as_input_variables = list(
                set(tax_benefit_system.variables.keys()).intersection(dataframe_variables)
            )

        elif "input_data_frame" in data:
            input_data_frame = data.get("input_data_frame")
            self.used_as_input_variables = list(
                set(tax_benefit_system.variables.keys()).intersection(set(input_data_frame.columns))
            )

        self.init_from_data(data=data, use_marginal_tax_rate=use_marginal_tax_rate)



from openfisca_core.model_api import *

from openfisca_senegal.entities import *


class TypesStatutMarital(Enum):
    __order__ = "marie celibataire veuf_divorce non_concerne"
    marie = "Marié"
    celibataire = "Célibataire"
    veuf_divorce = "Veuf ou divorcé"
    non_concerne = "Non concerné"


class est_marie(Variable):
    value_type = bool
    entity = Person
    label = "Est marié"
    set_input = set_input_dispatch_by_period
    definition_period = YEAR

    def formula(individu, period):
        return individu("statut_marital", period) == TypesStatutMarital.marie


class est_divorce(Variable):
    value_type = bool
    entity = Person
    label = "Est divorcé"
    definition_period = YEAR
    set_input = set_input_dispatch_by_period

    def formula(individu, period):
        return individu("statut_marital", period) == TypesStatutMarital.veuf_divorce


class est_veuf(Variable):
    value_type = bool
    entity = Person
    label = "Est veuf"
    definition_period = YEAR
    set_input = set_input_dispatch_by_period

    def formula(individu, period):
        return individu("statut_marital", period) == TypesStatutMarital.veuf_divorce


class est_celibataire(Variable):
    value_type = bool
    entity = Person
    label = "Est célibataire"
    definition_period = YEAR
    set_input = set_input_dispatch_by_period

    def formula(individu, period):
        return individu("statut_marital", period) == TypesStatutMarital.celibataire


class nombre_enfants(Variable):
    value_type = int
    entity = Person
    definition_period = YEAR


class date_naissance(Variable):
    value_type = date
    default_value = date(1970, 1, 1)
    entity = Person
    label = "Date de naissance"
    definition_period = ETERNITY


class age(Variable):
    value_type = int
    entity = Person
    definition_period = MONTH
    label = "Âge de l'individu (en années)"
    set_input = set_input_dispatch_by_period

    # A person's age is computed according to its birth date.
    def formula(individu, period, parameters):
        date_naissance = individu("date_naissance", period)
        birth_year = date_naissance.astype("datetime64[Y]").astype(int) + 1970
        birth_month = date_naissance.astype("datetime64[M]").astype(int) % 12 + 1
        birth_day = (date_naissance - date_naissance.astype("datetime64[M]") + 1).astype(int)

        is_birthday_past = (birth_month < period.start.month) + (birth_month == period.start.month) * (
            birth_day <= period.start.day
        )
        # If the birthday is not passed this year, subtract one year
        return (period.start.year - birth_year) - where(is_birthday_past, 0, 1)


class statut_marital(Variable):
    value_type = Enum
    possible_values = TypesStatutMarital
    default_value = TypesStatutMarital.non_concerne
    entity = Person
    label = "Statut marital"
    definition_period = YEAR



# This file defines the entities needed by our legislation.
from openfisca_core.entities import build_entity

Household = build_entity(
    key="household",
    plural="households",
    label="Household",
    doc="""
    Household is an example of a group entity.
    A group entity contains one or more individual·s.
    For more information, see: https://openfisca.org/doc/coding-the-legislation/50_entities.html
    """,
    roles=[
        {
            "key": "personne_de_reference",
            "label": "Personne de reference (Chef-fe de ménage)",
            "doc": "La personne de référence dans le ménage.",
            "max": 1,
        },
        {
            "key": "conjoint",
            "label": "Conjoint de la personne de référence",
            "doc": "Le/la conjoint-e de la personne de référence.",
            "max": 1,
        },
        {
            "key": "enfant",
            "plural": "enfants",
            "label": "Enfant",
            "doc": """Enfant à la charge de la personne de référence et de son conjoint
            - il peut y avoir d'autres enfant dans le ménage """,
        },
        {
            "key": "autre_membre",
            "plural": "autres_membres",
            "label": "Autres membres du ménage",
            "doc": "Membres du ménage différents de la personne de référence, de son/sa conjoint-e et de leurs enfants",
        },
    ],
)

Person = build_entity(
    key="person",
    plural="persons",
    label="Person",
    doc="""
    A Person represents an individual, the minimal legal entity on which a legislation might be applied.
    For more information, see: https://openfisca.org/doc/coding-the-legislation/50_entities.html
    """,
    is_person=True,
)

entities = [Household, Person]



from openfisca_senegal import CountryTaxBenefitSystem as SenegalTaxBenfitSystem
from openfisca_senegal.scenarios import init_single_entity


def test_senario():
    scenario = SenegalTaxBenfitSystem().new_scenario()
    init_single_entity(
        scenario,
        parent1={
            "salaire": 2800000,
            "est_marie": True,
            "conjoint_a_des_revenus": False,
            "nombre_enfants": 1,
        },
        period="2017",
    )
